==> redux-context-test-1.0.4.tgz: package/src/Provider.tsx <==
import React, { useMemo, FC } from 'react';
import { Reducer, Store, StoreEnhancer } from 'redux';
import Context from './Context.ts';
import createStore from './createStore.ts';

import { Store as CurrentStoreIns } from './types.ts';

type ProviderProps = {
  store: Store;
  name: string;
  middlewares?: StoreEnhancer;
  reducer: Reducer;
  preloadedState?: any;
  dispatchBubbles?: boolean;
}

type ContextValue = {
  store: CurrentStoreIns;
  parentStore: Store;
  name: string;
}

export const substores = new Map()
const storeDispatchCovers = new WeakMap()

const Provider: FC<ProviderProps> = ({
  store,
  name,
  middlewares,
  reducer,
  preloadedState,
  dispatchBubbles = true,
  children,
}) => {
  const value = useMemo<ContextValue>(() => {
    // 当前模块卸载时, store不会重新创建, 从map缓存中取, 防止数据丢失
    let currentSubStore = substores.get(name)

    if (!currentSubStore) {
      const substore = createStore(reducer, preloadedState, middlewares)

      substores.set(name, substore)
      currentSubStore = substore
    }
    const dispatch = currentSubStore.dispatch.bind(currentSubStore)
    // 防止当前模块内部store dispatch多次赋值, 避免多次调用父级的dispatch方法
    const hasCover = storeDispatchCovers.get(currentSubStore)

    if (!hasCover) {
      currentSubStore.dispatch = function (action: any) {
        storeDispatchCovers.set(currentSubStore, true)
        dispatch(action)

        if (dispatchBubbles) {
          store.dispatch(action)
        }
        return action
      }
    }

    return {
      name,
      store: currentSubStore,
      parentStore: store,
    }
  }, [store, reducer, preloadedState])

  return (
    <Context.Provider value={value}>{children}</Context.Provider>
  );
}

export default Provider;

==> redux-context-test-1.0.8.tgz: package/src/Provider.tsx <==
import React, { useMemo, FC } from 'react';
import { Reducer, Store, StoreEnhancer } from 'redux';
import Context from './Context';
import createStore from './createStore';

import { Store as CurrentStoreIns } from './types';

type ProviderProps = {
  store: Store<any>;
  name: string;
  middlewares?: StoreEnhancer<any>;
  reducer: Reducer<any>;
  preloadedState?: any;
  dispatchBubbles?: boolean;
}

type ContextValue = {
  store: CurrentStoreIns;
  parentStore: Store<any>;
  name: string;
}

export const substores = new Map()
const storeDispatchCovers = new WeakMap()

const Provider: FC<ProviderProps> = ({
  store,
  name,
  middlewares,
  reducer,
  preloadedState,
  dispatchBubbles = true,
  children,
}) => {
  const value = useMemo<ContextValue>(() => {
    // 当前模块卸载时, store不会重新创建, 从map缓存中取, 防止数据丢失
    let currentSubStore = substores.get(name)

    if (!currentSubStore) {
      const substore = createStore(reducer, preloadedState, middlewares)

      substores.set(name, substore)
      currentSubStore = substore
    }
    const dispatch = currentSubStore.dispatch.bind(currentSubStore)
    // 防止当前模块内部store dispatch多次赋值, 避免多次调用父级的dispatch方法
    const hasCover = storeDispatchCovers.get(currentSubStore)

    if (!hasCover) {
      currentSubStore.dispatch = function (action: any) {
        storeDispatchCovers.set(currentSubStore, true)
        dispatch(action)

        if (dispatchBubbles) {
          store.dispatch(action)
        }
        return action
      }
    }

    return {
      name,
      store: currentSubStore,
      parentStore: store,
    }
  }, [store, reducer, preloadedState])

  return (
    <Context.Provider value={value}>{children}</Context.Provider>
  );
}

export default Provider;
